/**
 * Fonction appelée quand on (dé)coche la case de sélection globale
 * (dé)sélectionner toutes les cases à cocher de toutes les activités
 * @param id de la case globale
 */
function cocherDecocherTout(idCaseGlobale)
{
    // itérer sur la liste des éléments détails : 1 par couple <activité, tarif>
    var lesDetails = document.querySelectorAll("details.activite");
    for (var i = 0; i < lesDetails.length; ++i)
    {
        // itérer sur les personnes
        var lesH3 = lesDetails[i].querySelectorAll("h4.personne");
        cocherDecocherLesPersonnes(idCaseGlobale, lesH3);
    }
    // changer le message
    changerMessage(idCaseGlobale.nextElementSibling, idCaseGlobale);
}

/**
 * idem dans le cas des versements des personnes
*/
function cocherDecocherToutesLesPersonnes(idCaseGlobale)
{
    var lesH3 = document.querySelectorAll("h4.personne");
    cocherDecocherLesPersonnes(idCaseGlobale, lesH3);
    changerMessage(idCaseGlobale.nextElementSibling, idCaseGlobale);
}

function cocherDecocherLesPersonnes(idCaseGlobale, lesPersonnes)
{
    for (var j = 0; j < lesPersonnes.length; ++j)
    {
        // trouver l'élément total de la personne
        var idTotal = lesPersonnes[j].querySelector("span");
        // puis la case à cocher
        var fieldset = lesPersonnes[j].closest("details").querySelector("fieldset");
        var idCase = fieldset.querySelector("input");
        idCase.checked = idCaseGlobale.checked;
        // puis traiter toutes les cases de la personne
        cocherDecocherPersonne(idCase, idTotal, false);
    }
}

/**
 * Fonction appelée quand on (dé)coche la case globale d'une personne
 * - (dé)sélectionner toutes les cases à cocher
 * - faire le total des cases cochées et l'afficher
 *
 * @param id de la case qui a été cochée
 * @param id de l'élément où afficher le total
 * @param changer : vrai, s'il faut changer le message de la personne
 */
function cocherDecocherPersonne(idCase, idTotal, changer = true)
{
    // chercher le fieldset des versements
    var fieldset = idCase.closest("details").querySelector("fieldset");
    var listeCases = fieldset.querySelectorAll("input[type=checkbox]");
    for (var i = 0; i < listeCases.length; ++i)
    {
        listeCases[i].checked = idCase.checked;
    }
    // calculer et afficher le total
    var listeMontants = fieldset.querySelectorAll("span.montant");
    calculerTotal(listeCases, listeMontants, idTotal);
    // changer le message
    if (changer) { changerMessage(idCase.nextElementSibling, idCase); }
}

/**
 * Fonction appelée quand on (dé)coche la case d'un versement
 * Faire le total des cases cochées et l'afficher
 *
 * @param id de la case qui a été cochée
 * @param id de l'élément où afficher le total
 */
function cocherDecocherVersement(idCase, idTotal)
{
    var fieldset = idCase.closest("fieldset");
    var listeCases = fieldset.querySelectorAll("input[type=checkbox]");
    var listeMontants = fieldset.querySelectorAll("span.montant");
    calculerTotal(listeCases, listeMontants, idTotal);
}

/**
 * Faire le total des cases cochées et l'afficher
 * @param listes des cases
 * @param listes des montants associés
 * @param id de l'élément où afficher le total
*/
function calculerTotal(listeCases, listeMontants, idTotal)
{
    var total = 0;
    for (var i = 1; i < listeCases.length; ++i)
    {
        if (listeCases[i].checked) {
            total += parseFloat(listeMontants[i-1].textContent.replace(/\s/g, ""));
        }
    }
    // "afficher" le total
    idTotal.innerHTML =
        total.toLocaleString('fr-FR', {style: 'currency', currency: 'EUR',
                                       minimumFractionDigits: 2});
}

/**
 * changer le message en fonction de l'état coché de la case
*/
function changerMessage(message, idCase)
{
    if (idCase.checked) {
        message.innerHTML = "Cliquer pour dé-cocher toutes les lignes";
    } else {
        message.innerHTML = "Cliquer pour cocher toutes les lignes";
    }
}

/**
 * fonction appelée lors de la validation du formulaire
 * @return vrai si au moins un choix a été fait
 * @param : formulaire
*/
function verifierChoix(formulaire)
{
    var listeCheck = formulaire.getElementsByTagName("input");
    var ok = false;
    for (var i = 1; i < listeCheck.length; ++i)
    {
	if (listeCheck[i].checked)
	{
	    ok = true;
	    break;
	}
    }
    if (! ok)
    {
	alert("Erreur : il faut sélectionner au moins un versement");
    }
    return ok;
}

/**
 * fonction appelée pour afficher et masquer des portions de formulaire
*/
function afficherMasquer(formulaire, nomClasse1, nomClasse2)
{
    for (var elem of formulaire.querySelectorAll(nomClasse1)) {
        elem.classList.remove('hidden');
    }
    for (var elem of formulaire.querySelectorAll(nomClasse2)) {
        elem.classList.add('hidden');
    }
}

// vérifier 
// - qu'au moins une activité/tarif est sélectionnée
// - qu'un radio de chaque activité/tarif sélectionné a été sélectionné :)
function verifierCases(idElem)
{
    var div = document.getElementById(idElem);
    var nbChoix = 0;
    // parcourir les cases à cocher
    for (var idCase of div.querySelectorAll("input[type=checkbox]"))
    {
        if (idCase.checked) {
            ++nbChoix;
            // vérifier qu'un radio de la même ligne est sélectionné
            var ligneCorrecte = false;
            // trouver la ligne englobante
            var ligne = idCase.closest("tr");
            for (var idRadio of ligne.querySelectorAll('input[type=radio]'))
            {
                if (idRadio.checked) { ligneCorrecte = true; break; }
            }
            if (! ligneCorrecte) {
                alert("Erreur : il faut sélectionner un taux de réduction dans chaque ligne cochée");
                return false;
            }
        }
    }
    if (nbChoix == 0) {
        alert("Erreur : il faut sélectionner au moins une activité/tarif");
    }
    return nbChoix != 0;
}

// vérifier qu'un radio a été sélectionné dans la div paramètre
function verifierRadio(idElem)
{
    var div = document.getElementById(idElem);
    for (var idRadio of div.querySelectorAll('input[type=radio]'))
    {
        if (idRadio.checked) { return true; }
    }
    alert("Erreur : il faut sélectionner un taux de réduction");
    return false;    
}

function montrerMasquerDetails(idElem, classe, texte)
{
    var lesDetails = document.querySelectorAll(classe);
    if (lesDetails.length > 0)
    {
        var leBouton = document.getElementById(idElem);
        if (leBouton.textContent.startsWith('Replier'))
        {
            // masquer
            lesDetails.forEach((e) => {
                e.removeAttribute('open');
            });
            leBouton.textContent = "Déplier " + texte;
            leBouton.setAttribute('data-icon', '↓');
        }
        else
        {
            // montrer
            lesDetails.forEach((e) => {
                e.setAttribute('open', 'open');
            });
            leBouton.textContent = "Replier " + texte;
            leBouton.setAttribute('data-icon', '↑');
        }
    }
}
